export declare type OrganizationStatus = 'Submitted' | 'Denied' | 'Active';
export declare const OrganizationStatus: {
    Submitted: OrganizationStatus;
    Denied: OrganizationStatus;
    Active: OrganizationStatus;
};
export interface PublicOrganizationInfoDTO {
    id: number;
    name: string;
    address: string;
    zipCode: string;
    city: string;
    country: string;
    businessType: string;
    tradeRegistryCompanyNumber: string;
    vatNumber: string;
    status: OrganizationStatus;
}
export interface BeneficiaryDTO {
    id: number;
    irecBeneficiaryId: number;
    organization: PublicOrganizationInfoDTO;
    ownerId: number;
    name: string;
    countryCode: string;
    location: string;
    active: boolean;
}
export interface AddBeneficiaryDto {
    irecBeneficiaryId: number;
}
export interface CreateBeneficiaryDto {
    name: string;
    countryCode: string;
    location: string;
}
export interface RegisterUserDTO {
    title: string;
    firstName: string;
    lastName: string;
    email: string;
    telephone: string;
    password: string;
}
export declare type UserStatus = 'Pending' | 'Active' | 'Suspended' | 'Deleted';
export declare const UserStatus: {
    Pending: UserStatus;
    Active: UserStatus;
    Suspended: UserStatus;
    Deleted: UserStatus;
};
export declare type KYCStatus = 'Pending' | 'Passed' | 'Rejected';
export declare const KYCStatus: {
    Pending: KYCStatus;
    Passed: KYCStatus;
    Rejected: KYCStatus;
};
export interface FullOrganizationInfoDTO {
    id: number;
    name: string;
    address: string;
    zipCode: string;
    city: string;
    country: string;
    businessType: string;
    tradeRegistryCompanyNumber: string;
    vatNumber: string;
    status: OrganizationStatus;
    signatoryFullName: string;
    signatoryAddress: string;
    signatoryZipCode: string;
    signatoryCity: string;
    signatoryCountry: string;
    signatoryEmail: string;
    signatoryPhoneNumber: string;
    documentIds?: string[];
    signatoryDocumentIds?: string[];
    blockchainAccountAddress?: string;
    blockchainAccountSignedMessage?: string;
}
export interface UserDTO {
    id: number;
    title: string;
    firstName: string;
    lastName: string;
    email: string;
    telephone: string;
    notifications: boolean;
    rights: number;
    status: UserStatus;
    kycStatus: KYCStatus;
    organization: FullOrganizationInfoDTO;
    emailConfirmed?: boolean;
}
export interface UpdateOwnUserSettingsDTO {
    notifications: boolean;
}
export interface UpdateUserProfileDTO {
    firstName: string;
    lastName: string;
    email: string;
    telephone: string;
}
export interface UpdatePasswordDTO {
    oldPassword: string;
    newPassword: string;
}
export interface SuccessResponseDTO {
    success: boolean;
    message?: string;
}
export declare type OrganizationInvitationStatus = 'Pending' | 'Rejected' | 'Accepted' | 'Viewed';
export declare const OrganizationInvitationStatus: {
    Pending: OrganizationInvitationStatus;
    Rejected: OrganizationInvitationStatus;
    Accepted: OrganizationInvitationStatus;
    Viewed: OrganizationInvitationStatus;
};
export interface InvitationDTO {
    id: number;
    email: string;
    role: number;
    status: OrganizationInvitationStatus;
    organization: PublicOrganizationInfoDTO;
    sender: string;
    createdAt: string;
}
export interface User {
    id: number;
    title: string;
    firstName: string;
    lastName: string;
    email: string;
    telephone: string;
    password: string;
    organization: Organization;
    rights: number;
    status: UserStatus;
    kycStatus: KYCStatus;
}
export declare type Role = 'OrganizationAdmin' | 'OrganizationDeviceManager' | 'OrganizationUser' | 'Issuer' | 'Admin' | 'SupportAgent';
export declare const Role: {
    OrganizationAdmin: Role;
    OrganizationDeviceManager: Role;
    OrganizationUser: Role;
    Issuer: Role;
    Admin: Role;
    SupportAgent: Role;
};
export interface Invitation {
    id: number;
    email: string;
    role: Role;
    status: OrganizationInvitationStatus;
    sender: string;
}
export interface Organization {
    id: number;
    name: string;
    address: string;
    zipCode: string;
    city: string;
    country: string;
    tradeRegistryCompanyNumber: string;
    vatNumber: string;
    signatoryFullName: string;
    signatoryAddress: string;
    signatoryZipCode: string;
    signatoryCity: string;
    signatoryCountry: string;
    signatoryEmail: string;
    signatoryPhoneNumber: string;
    signatoryDocumentIds: string[];
    status: OrganizationStatus;
    users: User[];
    invitations: Invitation[];
    documentIds: string[];
}
export interface NewOrganizationDTO {
    name: string;
    address: string;
    zipCode: string;
    city: string;
    country: string;
    businessType: string;
    tradeRegistryCompanyNumber: string;
    vatNumber: string;
    signatoryFullName: string;
    signatoryAddress: string;
    signatoryZipCode: string;
    signatoryCity: string;
    signatoryCountry: string;
    signatoryEmail: string;
    signatoryPhoneNumber: string;
    documentIds?: string[];
    signatoryDocumentIds?: string[];
}
export interface OrganizationUpdateDTO {
    status: OrganizationStatus;
}
export interface UpdateMemberDTO {
    role: number;
}
export interface BindBlockchainAccountDTO {
    signedMessage: string;
}
export interface FileUploadDto {
    files: unknown[];
}
export interface FileDto {
    data: unknown;
}
export interface LoginDataDTO {
    username: string;
    password: string;
}
export interface LoginReturnDataDTO {
    accessToken: string;
}
export interface ExternalDeviceIdTypeDTO {
    type: string;
    autogenerated?: boolean;
    required?: boolean;
}
export declare type ConfigurationDTORegions = {};
export interface ConfigurationDTO {
    countryName?: string;
    currencies?: string[];
    regions?: ConfigurationDTORegions;
    externalDeviceIdTypes?: ExternalDeviceIdTypeDTO[];
    complianceStandard?: string;
    deviceTypes?: string[][];
    gridOperators?: string[];
}
export interface InviteDTO {
    email: string;
    role: number;
}
export interface UpdateUserDTO {
    title: string;
    firstName: string;
    lastName: string;
    email: string;
    telephone: string;
    status: UserStatus;
    kycStatus: KYCStatus;
}
export interface UpdateBlockchainAccountDTO {
    address: string;
    signedMessage?: string;
}
export interface CreateConnectionDTO {
    userName: string;
    password: string;
    clientId: string;
    clientSecret: string;
}
export interface ShortConnectionDTO {
    expiryDate: string;
    userName: string;
    clientId: string;
    active: boolean;
}
export interface AccountDetailsDTO {
    name: string;
    private: boolean;
    restricted: boolean;
    active: boolean;
    notes: string;
    countryCode: string;
}
export declare type AccountDTOType = 'Trade' | 'Redemption' | 'Issue';
export declare const AccountDTOType: {
    Trade: AccountDTOType;
    Redemption: AccountDTOType;
    Issue: AccountDTOType;
};
export interface AccountDTO {
    code: string;
    type: AccountDTOType;
    details: AccountDetailsDTO;
}
export declare type IRECAccountType = 'Registrant' | 'Participant' | 'Both';
export declare const IRECAccountType: {
    Registrant: IRECAccountType;
    Participant: IRECAccountType;
    Both: IRECAccountType;
};
export interface RegistrationDTO {
    accountType: IRECAccountType;
    headquarterCountry: string;
    registrationYear: number;
    employeesNumber: string;
    shareholders: string;
    website: string;
    activeCountries: string[];
    mainBusiness: string;
    ceoName: string;
    ceoPassportNumber: string;
    balanceSheetTotal: string;
    subsidiaries?: string;
    primaryContactOrganizationName: string;
    primaryContactOrganizationAddress: string;
    primaryContactOrganizationPostalCode: string;
    primaryContactOrganizationCountry: string;
    primaryContactName: string;
    primaryContactEmail: string;
    primaryContactPhoneNumber: string;
    primaryContactFax: string;
    leadUserTitle: string;
    leadUserFirstName: string;
    leadUserLastName: string;
    leadUserEmail: string;
    leadUserPhoneNumber: string;
    leadUserFax: string;
    id: string;
    owner: string;
}
export interface NewRegistrationDTO {
    accountType: IRECAccountType;
    headquarterCountry: string;
    registrationYear: number;
    employeesNumber: string;
    shareholders: string;
    website: string;
    activeCountries: string[];
    mainBusiness: string;
    ceoName: string;
    ceoPassportNumber: string;
    balanceSheetTotal: string;
    subsidiaries?: string;
    primaryContactOrganizationName: string;
    primaryContactOrganizationAddress: string;
    primaryContactOrganizationPostalCode: string;
    primaryContactOrganizationCountry: string;
    primaryContactName: string;
    primaryContactEmail: string;
    primaryContactPhoneNumber: string;
    primaryContactFax: string;
    leadUserTitle: string;
    leadUserFirstName: string;
    leadUserLastName: string;
    leadUserEmail: string;
    leadUserPhoneNumber: string;
    leadUserFax: string;
}
export interface RegisterResponseDTO {
    id: string;
}
export declare type AdminControllerGetUsersParams = {
    orgName?: string;
    status?: AdminControllerGetUsersStatus;
    kycStatus?: AdminControllerGetUsersKycStatus;
};
export declare type AdminControllerGetUsersStatus = 'Pending' | 'Active' | 'Suspended' | 'Deleted';
export declare const AdminControllerGetUsersStatus: {
    Pending: AdminControllerGetUsersStatus;
    Active: AdminControllerGetUsersStatus;
    Suspended: AdminControllerGetUsersStatus;
    Deleted: AdminControllerGetUsersStatus;
};
export declare type AdminControllerGetUsersKycStatus = 'Pending' | 'Passed' | 'Rejected';
export declare const AdminControllerGetUsersKycStatus: {
    Pending: AdminControllerGetUsersKycStatus;
    Passed: AdminControllerGetUsersKycStatus;
    Rejected: AdminControllerGetUsersKycStatus;
};
